@@ -42,12 +42,12 @@ from .gmpv214 import (
     AlertEvent,
     AlertMethod,
     AliveTest,
-    AssetType,
     CredentialFormat,
     CredentialType,
     EntityType,
     FeedType,
     FilterType,
+    HelpFormat,
     HostsOrdering,
     InfoType,
     PermissionSubjectType,
@@ -59,19 +59,18 @@ from .gmpv214 import (
     SnmpPrivacyAlgorithm,
     SortOrder,
     TicketStatus,
-    TimeUnit,
     UserAuthType,
     get_aggregate_statistic_from_string,
     get_alert_condition_from_string,
     get_alert_event_from_string,
     get_alert_method_from_string,
     get_alive_test_from_string,
-    get_asset_type_from_string,
     get_credential_format_from_string,
     get_credential_type_from_string,
     get_entity_type_from_string,
     get_feed_type_from_string,
     get_filter_type_from_string,
+    get_help_format_from_string,
     get_hosts_ordering_from_string,
     get_info_type_from_string,
     get_permission_subject_type_from_string,
@@ -83,7 +82,6 @@ from .gmpv214 import (
     get_snmp_privacy_algorithm_from_string,
     get_sort_order_from_string,
     get_ticket_status_from_string,
-    get_time_unit_from_string,
     get_user_auth_type_from_string,
 )
 from .ospv1 import Osp
@@ -96,12 +94,12 @@ __all__ = [
     "AlertEvent",
     "AlertMethod",
     "AliveTest",
-    "AssetType",
     "CredentialType",
     "CredentialFormat",
     "EntityType",
     "FeedType",
     "FilterType",
+    "HelpFormat",
     "HostsOrdering",
     "InfoType",
     "PermissionSubjectType",
@@ -113,19 +111,18 @@ __all__ = [
     "SnmpPrivacyAlgorithm",
     "SortOrder",
     "TicketStatus",
-    "TimeUnit",
     "UserAuthType",
     "get_aggregate_statistic_from_string",
     "get_alert_condition_from_string",
     "get_alert_event_from_string",
     "get_alert_method_from_string",
     "get_alive_test_from_string",
-    "get_asset_type_from_string",
     "get_credential_format_from_string",
     "get_credential_type_from_string",
     "get_entity_type_from_string",
     "get_feed_type_from_string",
     "get_filter_type_from_string",
+    "get_help_format_from_string",
     "get_hosts_ordering_from_string",
     "get_info_type_from_string",
     "get_permission_subject_type_from_string",
@@ -137,6 +134,5 @@ __all__ = [
     "get_snmp_privacy_algorithm_from_string",
     "get_sort_order_from_string",
     "get_ticket_status_from_string",
-    "get_time_unit_from_string",
     "get_user_auth_type_from_string",
 ]
